<?php

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;

use Teknisa\CNC\Utilities\UtilCNC;
use Teknisa\Libs\Util\Environment;

use Teknisa\CNC\Services\Cnc01200TaxaParcelaAdquirenteService;

class Cnc01200TaxaParcelaAdquirente extends \Teknisa\CNC\Controllers\TeknisaCrud {
    protected $dataSourceName = 'cnc01200_taxa_parcela_view_grid';
    protected $parameterBagColumns;
    protected $taxaParcelaService;
    protected $environment;
    protected $nrseq;

    public function __construct($crudService, UtilCNC $util, Cnc01200TaxaParcelaAdquirenteService $taxaParcelaService, Environment $environment) {
        $this->crudService =$crudService;
        $this->util = $util;
        $this->taxaParcelaService = $taxaParcelaService;
        $this->environment = $environment;
    }

    public function saveNewRow (DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $insertNewTaxa = function ($row) {
                if (is_object($row))
                    $row = (array) $row;

                $row['NRORG'] = $this->environment->getNrOrgTrab();
                $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
                $row['DTULTATU'] = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
                $row['NRORGULTATU'] = $this->environment->getNrOrgTrab();
                $row['CDOPERULTATU'] = $this->environment->getCdOperador();

                $row['NRTAXAADQPARC'] = intval($this->util->newCode('TAXAADQPARC', '10'));

                $this->taxaParcelaService->saveNewTaxa($row);
                // the feels...
                $this->setNrseq($row['NRTAXAADQPARC']);
            };

            array_walk($rows, $insertNewTaxa);
            // quando vc n sabe usar __columns_to_return...
            $dataSet = [$this->getNrseq()];
            $response->addDataSet(new DataSet('dataSet', $dataSet));
            $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function save (DTO\Request $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            $this->taxaParcelaService->validadeEdit($rows);
            parent::save($request, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    // e manda o set e get na tora mesmo xDDDD
    public function setNrseq ($nrseq) {
        $this->nrseq = $nrseq;
    }

    public function getNrseq () {return $this->nrseq;}
}