<?php
namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\Report\ReportService;

use Teknisa\CNC\Services\Cnc02100VendasAntecipadasReportService;

class Cnc02100VendasAntecipadasReport extends \Zeedhi\Framework\Controller\Report {

    protected $birtStrategy;
    protected $myService;

    public function __construct(ReportService $service, $birtStrategy, Cnc02100VendasAntecipadasReportService $myService) {
        $this->birtStrategy = $birtStrategy;
        parent::__construct($service);
        $this->myService = $myService;
    }

    protected $reportMapping = array (
        "venda_antecipada" => array (
            "strategy" => "BIRT",
            "parameterMapping" => array (
                "dtvenda_ini"   => "dtvenda_ini",
                "dtvenda_fin"   => "dtvenda_fin",
                "nrestabelec"   => "nrestabelec",
                "nradquirente"  => "nradquirente",
                "nrorg"         => "nrorg",
                "nrprodutoadq"  => "nrprodutoadq",
                "vrvenda_min"   => "vrvenda_min",
                "vrvenda_max"   => "vrvenda_max",
                "vrvenda"       => "vrvenda"
            )
        )
    );

    public function validateReport (DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $result = $this->myService->validateReport($row);
            $response->addDataSet(new DataSet('cnc02100_vendas_antecipadas_report_validation', [$result]));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

}