<?php 

namespace Teknisa\CNC\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;

use Teknisa\CNC\Services\Cnc00300ProdutoAdquirenteService;

use Teknisa\Libs\Util\Environment;

class ProdutoAdquirenteEstabelec extends \Teknisa\CNC\Controllers\TeknisaCrud {
    protected $dataSourceName = 'cnc00300_produtoadquirente_estabelec';
	protected $parameterBagColumns;
	protected $produtoService;
	protected $environment;
	
	public function __construct($crudService, $parameterBag, Cnc00300ProdutoAdquirenteService $produtoService, Environment $environment) {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->produtoService = $produtoService;
        $this->environment = $environment;
    }
    
    public function save (DTO\Request $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows();
            $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            
            foreach ($rows as $row) {
                
                if (is_object($row))
                    $row = (array) $row;
                    
                if ($row['VRTAXAADM'] > 100)
                    throw new \Exception('Taxa superior ao limite de 100% (cem porcento).');
                
                $row['VRTAXAADM'] = round($row['VRTAXAADM'], 5);
                    
                $row['NRORG'] = $this->environment->getNrOrgTrab();
                $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
                $row['DTULTATU'] = $currentTime;
                $row['NRORGULTATU'] = $this->environment->getNrOrgTrab();
                $row['CDOPERULTATU'] = $this->environment->getCdOperador();
                $row['CDFILIALCON'] = $row['CDFILIAL'];
                
                $paramFetch = array(
                    ':NRORG'        => $row['NRORG'],
                    ':IDATIVO'      => $row['IDATIVO']
                );
                
                $result = $this->produtoService->getNrSequencialTaxaProdAdq($paramFetch);
                if (!isset($result[0]))
                    $row['NRSEQUENCIAL'] = 1;
                else
                    $row['NRSEQUENCIAL'] = $result[sizeof($result) - 1]['NRSEQUENCIAL'] + 1;
                
                $params = array(
                    ':CDFILIALCON'  => $row['CDFILIALCON'],
                    ':VRTAXAADM'    => $row['VRTAXAADM'],
                    ':NRSEQUENCIAL' => $row['NRSEQUENCIAL'],
                    ':NRSEQADQ'     => $row['NRSEQADQ'],
                    ':NRSEQPRODADQ' => $row['NRSEQPRODADQ'],
                    ':NRORG'        => $row['NRORG'],
                    ':IDATIVO'      => $row['IDATIVO'],
                    ':DTULTATU'     => $row['DTULTATU'],
                    ':NRORGULTATU'  => $row['NRORGULTATU'],
                    ':CDOPERULTATU' => $row['CDOPERULTATU']
                );
                
                $this->produtoService->saveProdutoFilial($params);
                $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveEdit (DTO\Request $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
            $rows = $dataSet->getRows();
            $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
            
            foreach ($rows as $row) {
                
                if (is_object($row))
                    $row = (array) $row;
                    
                if ($row['VRTAXAADM'] > 100)
                    throw new \Exception('Taxa superior ao limite de 100% (cem porcento).');
                    
                $row['VRTAXAADM'] = round($row['VRTAXAADM'], 5);
                    
                $row['NRORG'] = $this->environment->getNrOrgTrab();
                $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
                $row['DTULTATU'] = $currentTime;
                $row['NRORGULTATU'] = $this->environment->getNrOrgTrab();
                $row['CDOPERULTATU'] = $this->environment->getCdOperador();
                $row['CDFILIALCON'] = $row['CDFILIAL'];
                
                $params = array(
                    ':CDFILIALCON'  => $row['CDFILIALCON'],
                    ':VRTAXAADM'    => $row['VRTAXAADM'],
                    ':NRSEQUENCIAL' => $row['NRSEQUENCIAL'],
                    ':NRSEQADQ'     => $row['NRSEQADQ'],
                    ':NRSEQPRODADQ' => $row['NRSEQPRODADQ'],
                    ':NRORG'        => $row['NRORG'],
                    ':IDATIVO'      => $row['IDATIVO'],
                    ':DTULTATU'     => $row['DTULTATU'],
                    ':NRORGULTATU'  => $row['NRORGULTATU'],
                    ':CDOPERULTATU' => $row['CDOPERULTATU']
                );
                
                $this->produtoService->saveEditProdutoFilial($params);
                $response->addNotification(new Notification("Dados salvos com sucesso!"), Notification::TYPE_SUCCESS);
            }
        } catch(\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
	public function remove (DTO\Request $request, DTO\Response $response) {
	    $dataSet = $request->getDataSet();
        $rows = $dataSet->getRows();
        
        foreach ($rows as $row) {
            
            if (is_object($row))
                $row = (array) $row;
                
            $row['NRORG'] = $this->environment->getNrOrgTrab();
            $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
            
            $params = array(
                ':NRORG'        =>  $row['NRORG'],
                ':IDATIVO'      =>  $row['IDATIVO'],
                ':NRSEQUENCIAL' =>  $row['NRSEQUENCIAL'],
                ':NRSEQADQ'     =>  $row['NRSEQADQ'],
                ':NRSEQPRODADQ' =>  $row['NRSEQPRODADQ'],
                ':CDFILIALCON'  =>  $row['CDFILIALCON']
            );
            
            $this->produtoService->deleteTaxaAdqProd($params);
            $response->addNotification(new Notification("Dados deletados com sucesso!"), Notification::TYPE_SUCCESS);
        }
	}
}